*** Program for generating plots in Czech
* The input dataset is taxbenchars_`t' (or wintervals_`t' for tax rate intervals)

capture program drop plotscz
program define plotscz
args t
	capture log close
	clear
	capture clear matrix
	set more off
	set memory 512m

* We will often times plot and compute summary stats for annual incomes above at least one monthly minimum wage
* Set the minimum here as a parameter to be able to change it in one step
cd output_`t' 
use taxbenchars_`t'
 
*** PLOTS ***
capture mkdir plotscz_`t'
cd plotscz_`t'

*** ATR 
* set minimum and maximum ATR
scalar y0 = -0.15
scalar y1 = 0.7
* set min and max income
scalar inclb = 7999
scalar incub= 2000000
* ATR for combining by wage/business
lpoly pATR_w_`t' ginc_w if ginc_w>inclb & ginc_w<incub & pATR_w_`t'<y1 & pATR_w_`t'>y0, title("prijmy ze zamestnani") xtitle("hruba mzda (Kc/rok)") ytitle("Prumerna danova sazba") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(ATR_w_title_cz, replace) 
lpoly pATR_b_`t' ginc_b if ginc_b>inclb & ginc_b<incub & pATR_b_`t'<y1 & pATR_b_`t'>y0, title("prijmy z podnikani") xtitle("hruby zisk (Kc/rok)") ytitle("") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(ATR_b_title_cz, replace) 
* ATR for combining with densities
lpoly pATR_w_`t' ginc_w if ginc_w>inclb & ginc_w<incub & pATR_w_`t'<y1 & pATR_w_`t'>y0, title("") xsca(alt) yline(0) xtitle("hruba mzda (Kc/rok)") ytitle("ATR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(ATR_w_cz, replace) 
lpoly pATR_b_`t' ginc_b if ginc_b>inclb & ginc_b<incub & pATR_b_`t'<y1 & pATR_b_`t'>y0, title("") xsca(alt) yline(0) xtitle("hruby zisk (Kc/rok)") ytitle("ATR") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(ATR_b_cz, replace) 
* Histograms of tax rates and incomes
hist pATR_w_`t' [fw=rpkoef] if ginc_w>inclb & ginc_w<incub & pATR_w_`t'<y1 & pATR_w_`t'>y0, frac horizontal xsca(alt) ysca(alt) yline(0) ytitle("ATR") xtitle("podil poplatniku") fxsize(33) name(hist_ATR_w_cz, replace) nodraw
hist pATR_b_`t' [fw=rpkoef] if ginc_b>inclb & ginc_b<incub & pATR_b_`t'<y1 & pATR_b_`t'>y0, frac horizontal xsca(alt) ysca(alt) yline(0) ytitle("ATR") xtitle("podil poplatniku") fxsize(33) name(hist_ATR_b_cz, replace) nodraw
hist ginc_w 	[fw=rpkoef] if ginc_w>inclb & ginc_w<incub & pATR_w_`t'<y1 & pATR_w_`t'>y0, frac xtitle("hruba mzda (Kc/rok)") ytitle("podil poplatniku") fysize(25) name(hist_ginc_w_cz, replace) nodraw
hist ginc_b 	[fw=rpkoef] if ginc_b>inclb & ginc_b<incub & pATR_b_`t'<y1 & pATR_b_`t'>y0, frac xtitle("hruby zisk (Kc/rok)") ytitle("podil poplatniku") fysize(25) name(hist_ginc_b_cz, replace) nodraw
* Combine ATR and histograms
graph combine ATR_w_cz hist_ATR_w_cz hist_ginc_w_cz, title("Prumerne danove sazby: prijmy ze zamestnani") imargin() saving(ATR_w_densities_cz, replace)  nodraw
graph combine ATR_b_cz hist_ATR_b_cz hist_ginc_b_cz, title("Prumerne danove sazby: prijmy z podnikani") imargin() saving(ATR_b_densities_cz, replace)  nodraw
* Combine work and business
graph combine ATR_w_title_cz ATR_b_title_cz, title("Prumerne danove sazby") saving(ATR_w_b_cz, replace)  nodraw
* Histograms of ATR work and business together
twoway hist pATR_b_`t' [fw=rpkoef] if ginc_b>inclb & ginc_b<incub & pATR_b_`t'<y1 & pATR_b_`t'>y0,  fcolor(edkblue) lcolor(edkblue) fintensity(inten80) legend(label(1 "prijmy z podnikani")) start(-0.15) width(0.01) frac || hist pATR_w_`t' [fw=rpkoef] if ginc_w>inclb & ginc_w<incub & pATR_w_`t'<y1 & pATR_w_`t'>y0, frac fcolor(dkorange) lwidth(vthin) lcolor(dkorange) fintensity(inten80) legend(label(2 "prijmy ze zamestnani")) barwidth(0.005) start(-0.15) width(0.01) xtitle("prumerna danova sazba") ytitle("podil poplatniku") saving(hist_ATR_w_b_cz, replace) title("Rozdeleni prumernych danovych sazeb") nodraw


*** EMTR - tax and ben
* set minimum and maximum MTR
scalar y0 = -0.2
scalar y1 = 1
* set min and max income
scalar inclb = 7999
scalar incub= 2000000
* EMTR for combibing by wage and business
lpoly mtr_all_w_`t' ginc_w if ginc_w>inclb & ginc_w<incub & mtr_all_w_`t'<y1 & mtr_all_w_`t'>y0, title("prijmy ze zamestnani")  xtitle("hruba mzda (Kc/rok)") ytitle("EMTR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(MTR_all_w_title_cz, replace)
lpoly mtr_all_b_`t' ginc_b if ginc_b>inclb & ginc_b<incub & mtr_all_b_`t'<y1 & mtr_all_b_`t'>y0, title("prijmy z podnikani") xtitle("hruby zisk (Kc/rok)") ytitle("") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(MTR_all_b_title_cz, replace) 
* EMTR for combining with densities
lpoly mtr_all_w_`t' ginc_w if ginc_w>inclb & ginc_w<incub & mtr_all_w_`t'<y1 & mtr_all_w_`t'>y0, title("") xtitle("hruba mzda (Kc/rok)") ytitle("EMTR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(MTR_all_w_cz, replace) 
lpoly mtr_all_b_`t' ginc_b if ginc_b>inclb & ginc_b<incub & mtr_all_b_`t'<y1 & mtr_all_b_`t'>y0, title("") xtitle("hruby zisk (Kc/rok)") ytitle("EMTR") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(MTR_all_b_cz, replace) 
* Histograms of tax rates 
* (Histogram of income already exists)
hist mtr_all_w_`t' [fw=rpkoef] if ginc_w>inclb & ginc_w<incub & mtr_all_w_`t'<y1 & mtr_all_w_`t'>y0, frac horizontal ysca(alt) ytitle("EMTR") xtitle("podil poplatniku") fxsize(33) name(hist_MTR_all_w_cz, replace) nodraw
hist mtr_all_b_`t' [fw=rpkoef] if ginc_b>inclb & ginc_b<incub & mtr_all_b_`t'<y1 & mtr_all_b_`t'>y0, frac horizontal ysca(alt) ytitle("EMTR") xtitle("podil poplatniku") fxsize(33) name(hist_MTR_all_b_cz, replace) nodraw
* Combine EMTR and histogram
graph combine MTR_all_w_cz hist_MTR_all_w_cz, title("Efektivni mezni danove sazby: prijmy ze zamestnani") imargin() saving(MTR_all_w_densities_cz, replace) nodraw
graph combine MTR_all_b_cz hist_MTR_all_b_cz, title("Efektivni mezni danove sazby: prijmy z podnikani") imargin() saving(MTR_all_b_densities_cz, replace) nodraw
* Combine work and business
graph combine MTR_all_w_title_cz MTR_all_b_title_cz, title("Efektivni mezni danove sazby") saving(MTR_all_w_b_cz, replace) nodraw

*** MTR - tax 
* MTR for combining work and business
lpoly mtr_tax_w_`t' ginc_w if ginc_w>inclb & ginc_w<incub & mtr_tax_w_`t'<y1 & mtr_tax_w_`t'>y0, title("prijmy ze zamestnani") xtitle("hruba mzda (Kc/rok)") ytitle("MTR") fxsize(100) note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(MTR_tax_w_title_cz, replace) 
lpoly mtr_tax_b_`t' ginc_b if ginc_b>inclb & ginc_b<incub & mtr_tax_b_`t'<y1 & mtr_tax_b_`t'>y0, title("prijmy z podnikani") xtitle("hruby zisk (Kc/rok)") ytitle("") fxsize(100) note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(MTR_tax_b_title_cz, replace) 
* MTR for combining with densities
lpoly mtr_tax_w_`t' ginc_w if ginc_w>inclb & ginc_w<incub & mtr_tax_w_`t'<y1 & mtr_tax_w_`t'>y0, title("") xtitle("hruba mzda (Kc/rok)") ytitle("") note("") fxsize(100) lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(MTR_tax_w_cz, replace) 
lpoly mtr_tax_b_`t' ginc_b if ginc_b>inclb & ginc_b<incub & mtr_tax_b_`t'<y1 & mtr_tax_b_`t'>y0, title("") xtitle("hruby zisk (Kc/rok)") ytitle("MTR") note("") fxsize(100) lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(MTR_tax_b_cz, replace) 
* Histogram of tax rates
hist mtr_tax_w_`t' [fw=rpkoef] if ginc_w>inclb & ginc_w<incub & mtr_tax_w_`t'<y1 & mtr_tax_w_`t'>y0, frac horizontal ysca(alt) ytitle("MTR") xtitle("podil poplatniku") fxsize(33) name(hist_MTR_tax_w_cz, replace) nodraw
hist mtr_tax_b_`t' [fw=rpkoef] if ginc_b>inclb & ginc_b<incub & mtr_tax_b_`t'<y1 & mtr_tax_b_`t'>y0, frac horizontal ysca(alt) ytitle("MTR") xtitle("podil poplatniku") fxsize(33) name(hist_MTR_tax_b_cz, replace) nodraw
* Combine MTR-tax and histogram
graph combine MTR_tax_w_cz hist_MTR_tax_w_cz, title("Mezni danove sazby: prijmy ze zamestnani") imargin() saving(MTR_tax_w_densities_cz, replace) nodraw
graph combine MTR_tax_b_cz hist_MTR_tax_b_cz, title("Mezni danove sazby: prijmy z podnikani") imargin() saving(MTR_tax_b_densities_cz, replace) nodraw
* Combine work and business
graph combine MTR_tax_w_title_cz MTR_tax_b_title_cz, ycommon title("Mezni danove sazby") saving(MTR_tax_w_b_cz, replace) nodraw

* MTR for combining work and business with densities
lpoly mtr_tax_w_`t' ginc_w if ginc_w>inclb & ginc_w<incub & mtr_tax_w_`t'<y1 & mtr_tax_w_`t'>y0, title("") xtitle("hruba mzda (Kc/rok)") ytitle("Mezni danova sazba") note("") fxsize(100) lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(MTR_tax_w_cz, replace) 
lpoly mtr_tax_b_`t' ginc_b if ginc_b>inclb & ginc_b<incub & mtr_tax_b_`t'<y1 & mtr_tax_b_`t'>y0, title("") xtitle("hruby zisk (Kc/rok)") ytitle("Mezni danova sazba") note("") fxsize(100) lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(MTR_tax_b_cz, replace) 
* Histogram of tax rates
hist mtr_tax_w_`t' [fw=rpkoef] if ginc_w>inclb & ginc_w<incub & mtr_tax_w_`t'<y1 & mtr_tax_w_`t'>y0, frac horizontal ysca(alt) ytitle("") xtitle("podil poplatniku") fxsize(40) name(hist_MTR_tax_w_cz, replace) nodraw
hist mtr_tax_b_`t' [fw=rpkoef] if ginc_b>inclb & ginc_b<incub & mtr_tax_b_`t'<y1 & mtr_tax_b_`t'>y0, frac horizontal ysca(alt) ytitle("") xtitle("podil poplatniku") fxsize(40) name(hist_MTR_tax_b_cz, replace) nodraw
* Combine MTR-tax and histogram, separately for work and business
graph combine MTR_tax_w_cz hist_MTR_tax_w_cz, title("prijmy ze zamestnani") imargin() name(MTR_tax_w_densities_czwt, replace) nodraw
graph combine MTR_tax_b_cz hist_MTR_tax_b_cz, title("prijmy z podnikani") imargin() name(MTR_tax_b_densities_czwt, replace) nodraw
* Combine work and business, with histograms already
graph combine MTR_tax_w_densities_czwt MTR_tax_b_densities_czwt, ycommon title("Mezni danove sazby") saving(MTR_tax_w_b_densities_cz, replace) nodraw


*** EPTR working - tax and ben
* set minimum and maximum PTR
scalar y0 = -0.2
scalar y1 = 1
* set min and max income
scalar inclb = 7999
scalar incub= 2000000
* PTR - all for combining work and business
lpoly ptr_all_w_`t' ginc_w if ginc_w>inclb & ginc_w<incub & ptr_all_w_`t'<y1 & ptr_all_w_`t'>y0, title("prijmy ze zamestnani") xtitle("hruba mzda (Kc/rok)") ytitle("EPTR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(PTR_all_w_title_cz, replace) /*gen(lpoly_PTR_all_w_x lpoly_PTR_all_w_y)*/
lpoly ptr_all_b_`t' ginc_b if ginc_b>inclb & ginc_b<incub & ptr_all_b_`t'<y1 & ptr_all_b_`t'>y0, title("prijmy z podnikani") xtitle("hruby zisk (Kc/rok)") ytitle("") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(PTR_all_b_title_cz, replace) /*gen(lpoly_PTR_all_b_x lpoly_PTR_all_b_y)*/
* PTR - all for combining with histograms
lpoly ptr_all_w_`t' ginc_w if ginc_w>inclb & ginc_w<incub & ptr_all_w_`t'<y1 & ptr_all_w_`t'>y0, title("") xtitle("hruba mzda (Kc/rok)") ytitle("EPTR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(PTR_all_w_cz, replace)
lpoly ptr_all_b_`t' ginc_b if ginc_b>inclb & ginc_b<incub & ptr_all_b_`t'<y1 & ptr_all_b_`t'>y0, title("") xtitle("hruby zisk (Kc/rok)") ytitle("EPTR") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(PTR_all_b_cz, replace) 
* Histograms
hist ptr_all_w_`t' [fw=rpkoef] if ginc_w>inclb & ginc_w<incub & ptr_all_w_`t'<y1 & ptr_all_w_`t'>y0, frac horizontal ysca(alt) ytitle("EPTR") xtitle("podil poplatniku") fxsize(33) name(hist_PTR_all_w_cz, replace) nodraw
hist ptr_all_b_`t' [fw=rpkoef] if ginc_b>inclb & ginc_b<incub & ptr_all_b_`t'<y1 & ptr_all_b_`t'>y0, frac horizontal ysca(alt) ytitle("EPTR") xtitle("podil poplatniku") fxsize(33) name(hist_PTR_all_b_cz, replace) nodraw
* Combine work and business
graph combine PTR_all_w_title_cz PTR_all_b_title_cz, title("Participacni danove sazby: pracujici osoby") saving(PTR_all_w_b_cz, replace) nodraw
* Combine PTR and histograms
graph combine PTR_all_w_cz hist_PTR_all_w_cz, title("Participacni danove sazby") subtitle("pracujici osoby s prijmy ze zamestnani") imargin() saving(PTR_all_w_densities_cz, replace) nodraw
graph combine PTR_all_b_cz hist_PTR_all_b_cz, title("Participacni danove sazby") subtitle("pracujici osoby s prijmy z podnikani") imargin() saving(PTR_all_b_densities_cz, replace) nodraw


*** EPTR non-working - tax and ben
* set minimum and maximum PTR
scalar y0 = 0
scalar y1 = 1
* set min and max potential income
scalar inclb = 7999
scalar incpub= 600000

* PTRs non-working for combining part-time and full-time
lpoly ptr_all_w_f_`t' mzda_f if mzda_f>inclb & mzda_f<incpub & ptr_all_w_f_`t'<y1 & ptr_all_w_f_`t'>y0, title("prace na plny uvazek") xtitle("hruba mzda (Kc/rok)") ytitle("EPTR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(PTR_all_w_f_title_cz, replace) /*gen(lpoly_PTR_all_w_x lpoly_PTR_all_w_y)*/
lpoly ptr_all_w_p_`t' mzda_p if mzda_p>inclb & mzda_p<incpub & ptr_all_w_p_`t'<y1 & ptr_all_w_p_`t'>y0, title("prace na polovicni uvazek") xtitle("hruba mzda (Kc/rok)") ytitle("") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(PTR_all_w_p_title_cz, replace) /*gen(lpoly_PTR_all_b_x lpoly_PTR_all_b_y)*/
* PTRs for combining with histograms
lpoly ptr_all_w_f_`t' mzda_f if mzda_f>inclb & mzda_f<incpub & ptr_all_w_f_`t'<y1 & ptr_all_w_f_`t'>y0, title("") xtitle("hruba mzda (Kc/rok)") ytitle("EPTR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(PTR_all_w_f_cz, replace)
lpoly ptr_all_w_p_`t' mzda_p if mzda_p>inclb & mzda_p<incpub & ptr_all_w_p_`t'<y1 & ptr_all_w_p_`t'>y0, title("") xtitle("hruba mzda (Kc/rok)") ytitle("EPTR") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(PTR_all_w_p_cz, replace) 
* histograms of PTR's 
hist ptr_all_w_f_`t' [fw=rpkoef] if mzda_f>inclb & mzda_f<incpub & ptr_all_w_f_`t'<y1 & ptr_all_w_f_`t'>y0, frac horizontal ysca(alt) title("EPTR") xtitle("podil poplatniku") fxsize(33) name(hist_PTR_all_w_f_cz, replace) nodraw
hist ptr_all_w_p_`t' [fw=rpkoef] if mzda_p>inclb & mzda_p<incpub & ptr_all_w_p_`t'<y1 & ptr_all_w_p_`t'>y0, frac horizontal ysca(alt) ytitle("EPTR") xtitle("podil poplatniku") fxsize(33) name(hist_PTR_all_w_p_cz, replace) nodraw
* Combine part-time and full-time
graph combine PTR_all_w_f_title_cz PTR_all_w_p_title_cz, title("Participacni danove sazby: nepracujici osoby") saving(PTR_all_w_f_p_cz, replace) nodraw
* Combine with histograms
graph combine PTR_all_w_f_cz hist_PTR_all_w_f_cz, title("Participacni danove sazby") subtitle("nepracujici, pokud by zacali pracovat na plny uvazek") imargin() saving(PTR_all_w_f_densities_cz, replace) nodraw
graph combine PTR_all_w_p_cz hist_PTR_all_w_p_cz, title("Participacni danove sazby") subtitle("nepracujici, pokud by zacali pracovat na polovicni uvazek") imargin() saving(PTR_all_w_p_densities_cz, replace) nodraw


*** ATRs at HH level 
* set minimum and maximum HH ATR
scalar y0 = -0.2
scalar y1 = 0.6
*set minimun HH net ATR
scalar z0 = -1.01
* set maximum HH ABR
scalar x1 = 1.2
* set max household income
scalar inchhub = 1200000
* taxes and benefits combined in one
lpoly phhATR_tax_`t' hhginc_perunit if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_tax_`t'>=y0 & hhATR_tax_`t'<=y1, title("dane") ytitle("dane placene domacnosti / prijmy domacnosti") note("") yline(0) lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(hhATR_tax_cz, replace)
lpoly phhATR_ben_`t'  hhginc_perunit if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_ben_`t'<x1, title("davky") ytitle("davky pobirane domacnosti / prijmy domacnosti") note("") yline(0) lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(hhATR_ben_cz, replace)
graph combine hhATR_tax_cz hhATR_ben_cz, saving(hhATR_taxben_cz, replace) title("Domacnosti: prumerna danova a davkova sazba") note("neduchodcovske domacnosti s kladnymi prijmy") nodraw
* ATRs for combining with densities
lpoly phhATR_tax_`t'  hhginc_perunit if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_tax_`t'>=y0 & hhATR_tax_`t'<=y1, xsca(alt) title("") ytitle("prumerna danova sazba") xtitle("hruba mzda domacnosti na jednotku, Kc/rok") note("") yline(0) lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(hhATR_tax_cz, replace)
lpoly phhATR_all_`t'  hhginc_perunit if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_all_`t'>z0 & hhATR_all_`t'<=y1, title("") xsca(alt) yline(0) xtitle("hruba mzda domacnosti na jednotku, Kc/rok") ytitle("prumerna cista danova sazba") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(hhATR_all_cz, replace) 
lpoly phhATR_ben_`t'  hhginc_perunit if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_ben_`t'<x1, xsca(alt) title("") ytitle("prumerna davkova sazba") xtitle("hruba mzda domacnosti na jednotku, Kc/rok") note("") yline(0) lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(hhATR_ben_cz, replace)
* histograms 
hist hhginc_perunit	[fw=rpkoef] 	if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_tax_`t'>=y0 & hhATR_tax_`t'<=y1, frac xtitle("hruba mzda domacnosti na jednotku, Kc/rok") ytitle("podil domacnosti") fysize(20) name(hist_hhginc_cz, replace) nodraw
hist phhATR_all_`t' [fw=rpkoef] 	if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_all_`t'>z0 & hhATR_all_`t'<=y1, frac horizontal xsca(alt) ysca(alt) yline(0) ytitle("prumerna cista danova sazba") xtitle("podil domacnosti") fxsize(33) name(hist_hhATR_all_cz, replace) nodraw
hist phhATR_tax_`t' [fw=rpkoef] 	if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_tax_`t'>=y0 & hhATR_tax_`t'<=y1, frac horizontal xsca(alt) ysca(alt) yline(0) ytitle("prumerna danova sazba") xtitle("podil domacnosti") fxsize(33) name(hist_hhATR_tax_cz, replace) nodraw
hist phhATR_ben_`t' [fw=rpkoef] 	if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_ben_`t'<x1, frac horizontal xsca(alt) ysca(alt) yline(0) ytitle("prumerna davkova sazba") xtitle("podil domacnosti") fxsize(33) name(hist_hhATR_ben_cz, replace) nodraw
* Combine with histograms
graph combine hhATR_tax_cz hist_hhATR_tax_cz hist_hhginc_cz, title("Domacnosti: prumerna danova sazba") note("neduchodcovske domacnosti s kladnymi prijmy") imargin() saving(hhATR_tax_densities_cz, replace)  nodraw
graph combine hhATR_all_cz hist_hhATR_all_cz, ycommon title("Domacnosti: prumerna cista danova sazba") note("neduchodcovske domacnosti s kladnymi prijmy") imargin() saving(hhATR_all_densities_cz, replace) nodraw
graph combine hhATR_ben_cz hist_hhATR_ben_cz, title("Domacnosti: prumerna davkova sazba") note("neduchodcovske domacnosti s kladnymi prijmy") imargin() saving(hhATR_ben_densities_cz, replace) nodraw
* Histograms of HH level ATR's 
hist phhATR_all_`t' [fw=rpkoef] 	if vztah==1 & hhnonpen==1 & hhginc_perunit<inchhub & hhATR_all_`t'>z0 & hhATR_all_`t'<=y1, frac horizontal xsca(alt) ysca(alt) yline(0) ytitle("Prumerna danova sazba, ciste dane") xtitle("podil domacnosti") fxsize(33) name(hist_hhATR_all_cz, replace) nodraw

*** Lorenz curve - Individual taxes
sort glvar_ginc_w pvar_ginc_w
twoway line glvar_totaltax_w_`t' glvar_ginc_w pvar_ginc_w pvar_ginc_w if ginc_w>inclb, ylabel(0 (0.1) 1, grid) xlabel(0 (0.1) 1, grid) xtitle("") name(lorenz_w_cz, replace ) legend(off) title("prijmy ze zamestnani") xtitle("")  nodraw
sort glvar_ginc_b pvar_ginc_b
twoway line glvar_totaltax_b_`t' glvar_ginc_b pvar_ginc_b pvar_ginc_b if ginc_b>inclb, ylabel(0 (0.1) 1, grid) xlabel(0 (0.1) 1, grid) xtitle("") name(lorenz_b_cz, replace ) legend(off) title("prijmy z podnikani") xtitle("") nodraw
sort glvar_ginc_i pvar_ginc_i
twoway line glvar_totaltax_i_`t' glvar_ginc_i pvar_ginc_i pvar_ginc_i if ginc_i>inclb, ylabel(0 (0.1) 1, grid) xlabel(0 (0.1) 1, grid) xtitle("") name(lorenz_i_cz, replace ) legend(off) title("celkove prijmy") xtitle("") nodraw
graph combine lorenz_w_cz lorenz_b_cz lorenz_i_cz, title("Lorenzovy krivky: prijmy a celkove dane") l2title("kumulativni podil prijmu nebo dani") b2title("kumulativni podil v populaci dle prijmu") saving(lorenz_indiv_cz, replace) nodraw

*** Lorenz curves - Household net taxes
sort glvar_hhginc_pu pvar_hhginc_pu
twoway line glvar_hhnettax_pu_`t' glvar_hhginc_pu pvar_hhginc_pu pvar_hhginc_pu if vztah==1 & hhnonpen==1, ylabel(0 (0.1) 1, grid) xlabel(0 (0.1) 1, grid) title("Lorenzovy krivky: prijmy a ciste dane domacnosti") subtitle("(na spotrebni jednotku)") xtitle("") legend(off) l2title("kumulativni podil prijmu nebo cistych dani") b2title("kumulativni podil v populaci dle prijmu") saving(lorenz_hh_cz, replace) nodraw

	cd ..
	cd ..
end

exit
